Umbra
=====

..  image:: https://secure.travis-ci.org/KelSolaar/Umbra.png?branch=master
..  image:: https://gemnasium.com/KelSolaar/Umbra.png  

Introduction
------------

Umbra is the main package of `sIBL_GUI <http://github.com/KelSolaar/sIBL_GUI>`_ and `sIBL_Reporter <http://github.com/KelSolaar/sIBL_Reporter>`_.

..  image:: http://thomasmansencal.com/Sharing/Umbra/Support/Documentation/Help/resources/pictures/Umbra_DevelopmentCentricLayout.jpg

Installation
------------

The following dependencies are needed:

-  **Python 2.6.7** or **Python 2.7.3**: http://www.python.org/
-  **PyQt**: http://www.riverbankcomputing.co.uk/

To install **Umbra** from the `Python Package Index <http://pypi.python.org/pypi/Umbra>`_ you can issue this command in a shell::

	pip install Umbra

or this alternative command::

	easy_install Umbra

You can also directly install from `Github <http://github.com/KelSolaar/Umbra>`_ source repository::

	git clone git://github.com/KelSolaar/Umbra.git
	cd Umbra
	python setup.py install

If you want to build the documentation you will also need:

-  **Tidy** http://tidy.sourceforge.net/

Usage
-----

Once installed, you can launch **Umbra** using this shell command::

	Umbra

Please refer to `Umbra - Api <http://thomasmansencal.com/Sharing/Umbra/Support/Documentation/Api/index.html>`_ for precise usage examples.

About
-----

| **Umbra** by Thomas Mansencal – 2010 - 2014
| Copyright © 2010 - 2014 – Thomas Mansencal – `thomas.mansencal@gmail.com <mailto:thomas.mansencal@gmail.com>`_
| This software is released under terms of GNU GPL V3 license: http://www.gnu.org/licenses/
| `http://www.thomasmansencal.com/ <http://www.thomasmansencal.com/>`_